function love.load()
	
	grid = {}
	traces = {}
	counter = 0
	
	screenx, screeny = love.graphics.getWidth(), love.graphics.getHeight()
	
	local iData = love.image.newImageData('pic2.png')	-- this doesn't need to be global
	
	for x = 1, 128 do
		grid[x] = {}
		for y = 1,128 do
			local r, g, b, a = iData:getPixel(x-1, y-1)
			
			if r == 255 and g == 0 and b == 0 then
				grid[x][y] = {r,g,b,a}
				table.insert(traces, {x=x,y=y})		-- traces table holds trace ends
			elseif r == 255 and g == 255 and b == 255 then
				grid[x][y] = {r,g,b,a}	-- I don't get why you want to save each pixel's color, but whatever, I kept that
			end
			
			-- pixels of other colors aren't added to the grid (and thus won't be traced over)
		end
	end
	
	local etch = love.audio.newSource('1.ogg')
	
	etch:setVolume(0.1)
	
	etch:play()
	
end

function love.draw()
	
	love.graphics.scale(4,4)	-- scale is very convenient here
	
	for x = 1, 128 do
		for y = 1, 128 do
			if grid[x][y] and grid[x][y].active then
				local check = math.random(1, 300)
				if check == 1 then
					love.graphics.setColor(255, 255, 0, 255)
				else
					love.graphics.setColor(0, 128, 128, 255)
				end
				love.graphics.rectangle('fill',x + ((((screenx - 512)/2)/4)-1), y + ((((screeny - 512)/2)/4)-1), 1, 1)
			end
		end
	end
	
	
end

function love.update(dt)
	dt = math.min(math.max(0, dt), .1)

	counter = counter + dt * 60	-- grow at 60 pixels per second
	
	
	if counter > 1 then
		counter = counter - 1
		
		for i=#traces,1,-1 do		-- this is the safe way to use table.remove on a table you're iterating on
			local t = traces[i]
			local x,y = t.x, t.y
			
			-- expand trace to adjacent pixels
			if grid[x][y-1] and not grid[x][y-1].active then table.insert(traces, {x=x, y=y-1}) end
			if grid[x][y+1] and not grid[x][y+1].active then table.insert(traces, {x=x, y=y+1}) end
			if grid[x-1] and grid[x-1][y] and not grid[x-1][y].active then table.insert(traces, {x=x-1, y=y}) end
			if grid[x+1] and grid[x+1][y] and not grid[x+1][y].active then table.insert(traces, {x=x+1, y=y}) end
			
			grid[x][y].active = true	-- this tells a pixel it may now be drawn
			table.remove(traces, i)
		end
		
	end
	
	if #traces == 0 then love.event.push('q') end
end

function love.keypressed(key)
	if key == 'r' then
		love.filesystem.load('main.lua')() love.load()
	end
end